# -*- coding: utf-8 -*-
{
    'name': "Sale Stock Margin",
    'category': 'Sales/Sales',
    'description': 'Once the delivery is validated, update the cost on the SO to have an exact margin computation.',
    'version': '0.1',
    'depends': ['sale_stock', 'sale_margin'],
    'installable': True,
    'auto_install': True,
    'license': 'LGPL-3',
}
